Name:		partclone
Version:	0.3.32
Release:	%mkrel 1
Summary:	File System Clone Utilities
Group:		Archiving/Backup
URL:		https://partclone.org/
License:	GPL-2.0-or-later
Source0:	https://github.com/Thomas-Tsai/partclone/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:	dpkg-dev
BuildRequires:	pkgconfig(ext2fs)
BuildRequires:	xfs-devel
BuildRequires:	pkgconfig(libntfs-3g)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	pkgconfig(libbsd)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	btrfs-devel
BuildRequires:	pkgconfig(blkid)
BuildRequires:	nilfs-utils-devel
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(fuse)
BuildRequires:	pkgconfig(mount)
BuildRequires:	pkgconfig(reiserfscore)
BuildRequires:	pkgconfig(bash-completion)

# Partclone depends on specific source files, either not exposed to -devel package or no -devel package exists
# Version information origin: src/btrfs/libbtrfs/version.h
Provides:	bundled(libbtrfs) = 6.8.1
Provides:	bundled(libbtrfsutil) = 6.8.1
# Version information origin: src/xfs/include/builddefs
Provides:	bundled(xfsprogs-libs) = 4.20.0

%description
Partclone is a program similar to the well-known backup utility "Partition
Image" a.k.a partimage. Partclone provides utilities to save and restore
used blocks on a partition and is designed for higher compatibility of the
file system by using existing libraries, e.g. e2fslibs is used to read and
write the ext2 partition.

Partclone now supports ext2, ext3, ext4, hfs+, btrfs, xfs, ntfs,
fat(12/16/32), exfat, f2fs, nilfs2.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
    --disable-rpath \
    --enable-apfs \
    --enable-ncursesw \
    --enable-fs-test \
    --enable-fuse \
    --enable-xfs \
    --enable-hfsp \
    --enable-fat \
    --enable-ntfs \
    --enable-btrfs \
    --enable-extfs \
    --enable-f2fs \
    --enable-nilfs2 \
    --enable-minix \
    --enable-exfat \
    --disable-reiserfs \
    --disable-reiser4 \
    --disable-ufs \
    --disable-vmfs \
    --disable-jfs

%make_build

%install
%make_install

# Building fail-mbr.bin requires a compiler that can build x86 binaries
%ifnarch %{ix86} x86_64
rm -rf %{buildroot}%{_datadir}/%{name}/
%endif

mv -f %{buildroot}%{_datadir}/bash-completion/completions/%{name}{-prompt,}

%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc AUTHORS ChangeLog NEWS README.md
%{_datadir}/bash-completion/completions/%{name}
%{_sbindir}/partclone.*
%ifarch %{ix86} x86_64
%dir %{_datadir}/partclone/
%{_datadir}/partclone/fail-mbr.bin
%endif
%{_mandir}/man8/partclone.*


%changelog
* Tue Jul 16 2024 daviddavid <daviddavid> 0.3.32-1.mga10
+ Revision: 2081663
- new version: 0.3.32

* Tue Jun 25 2024 daviddavid <daviddavid> 0.3.31-1.mga10
+ Revision: 2076546
- new version: 0.3.31

* Sat Jun 15 2024 daviddavid <daviddavid> 0.3.29-1.mga10
+ Revision: 2074128
- new version: 0.3.29

* Fri Jun 14 2024 daviddavid <daviddavid> 0.3.28-1.mga10
+ Revision: 2073080
- new version: 0.3.28

* Sun Oct 29 2023 daviddavid <daviddavid> 0.3.27-1.mga10
+ Revision: 2002699
- new version: 0.3.27

* Mon Feb 06 2023 luigiwalser <luigiwalser> 0.3.23-1.mga9
+ Revision: 1938766
- 0.3.23

* Tue Jan 17 2023 luigiwalser <luigiwalser> 0.3.22-1.mga9
+ Revision: 1934161
- 0.3.22
- remove upstream patch

* Sat May 07 2022 luigiwalser <luigiwalser> 0.3.20-1.mga9
+ Revision: 1856678
- BR libmount-devel
- 0.3.20
- add upstream patch via fedora

* Tue Mar 29 2022 luigiwalser <luigiwalser> 0.3.19-1.mga9
+ Revision: 1831299
- 0.3.19
- update source URL
- remove upstream patches

* Thu Dec 30 2021 wally <wally> 0.3.18-1.mga9
+ Revision: 1765387
- dont fail with 'files fail-mbr.bin and fail-mbr.bin.orig differ significantly'
- add upstream patches for openssl3
- ship fail-mbr.bin only with x86 arches
- rebuild for ntfs-3g 2021.8.22
- rebuild for openssl 3.0.0
+ luigiwalser <luigiwalser>
- BR dpkg-dev for dpkg-architecture
- add patch to fix format security error
- 0.3.18
- update source URL
+ tv <tv>
- Rebuild for updated ntfs-3g CVE

* Sun Dec 06 2020 luigiwalser <luigiwalser> 0.3.17-1.mga8
+ Revision: 1654005
- 0.3.17
- update source URL
- remove upstreamed gcc10 patch
- enable apfs and exfat

* Tue May 26 2020 neoclust <neoclust> 0.3.12-3.mga8
+ Revision: 1587713
- Fix build with gcc10

* Fri Feb 14 2020 umeabot <umeabot> 0.3.12-2.mga8
+ Revision: 1521728
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Dec 30 2018 luigiwalser <luigiwalser> 0.3.12-1.mga7
+ Revision: 1346842
- 0.3.12
- update source URL

* Sun Sep 23 2018 umeabot <umeabot> 0.3.11-2.mga7
+ Revision: 1300112
- Mageia 7 Mass Rebuild

* Wed Apr 18 2018 kekepower <kekepower> 0.3.11-1.mga7
+ Revision: 1219893
- Update to version 0.3.11

* Sat Jul 22 2017 daviddavid <daviddavid> 0.3.5a-2.mga7
+ Revision: 1128730
- rebuild for new ntfs-3g

* Mon Apr 24 2017 neoclust <neoclust> 0.3.5a-1.mga6
+ Revision: 1097243
- New version 0.3.5a - Fixes CVE-2017-6596 (mga#20594)

* Thu Aug 11 2016 luigiwalser <luigiwalser> 0.2.89-1.mga6
+ Revision: 1045561
- 0.2.89

* Wed May 18 2016 tv <tv> 0.2.88-1.mga6
+ Revision: 1016695
- BR ncursesw-devel
+ neoclust <neoclust>
- imported package partclone

